# Switcher Boiler Unofficial Bridge and API</br>[![pypi-version]][11] [![pypi-license]][11] [![pypi-downloads]][11]

[![gh-build-status]][7] [![read-the-docs]][8] [![codecov]][3] [![dependabot-status]][1]

PyPi module named [aioswitcher][11] for integrating with the [Switcher Water Heater](https://www.switcher.co.il/).</br>
Please check out the [documentation][8].

<!-- Real Links -->
[1]: https://dependabot.com
[2]: https://github.com/TomerFi/aioswitcher/releases
[3]: https://codecov.io/gh/TomerFi/aioswitcher
[7]: https://github.com/TomerFi/aioswitcher/actions?query=workflow%3ABuild
[8]: https://aioswitcher.tomfi.info/
[11]: https://pypi.org/project/aioswitcher/
<!-- Badges Links -->
[codecov]: https://codecov.io/gh/TomerFi/aioswitcher/graph/badge.svg
[dependabot-status]: https://api.dependabot.com/badges/status?host=github&repo=TomerFi/aioswitcher
[gh-build-status]: https://github.com/TomerFi/aioswitcher/workflows/Build/badge.svg
[pypi-downloads]: https://img.shields.io/pypi/dm/aioswitcher.svg?logo=pypi
[pypi-license]: https://img.shields.io/pypi/l/aioswitcher.svg?logo=pypi
[pypi-version]: https://img.shields.io/pypi/v/aioswitcher?logo=pypi
[read-the-docs]: https://readthedocs.org/projects/aioswitcher/badge/?version=stable
